from distillation.semiSupervised import *

__all__=['plainDistillation','dataDistillation','modelDistillation','modelDataDistillation']

plainDistillation.__module__='distillation'
dataDistillation.__module__='distillation'
modelDistillation.__module__='distillation'
modelDataDistillation.__module__='distillation'
